Learn R Programming

raptr (version 0.0.1)

is.GurobiInstalled: Test if Gurobi is installed on computer

Description

This function determines if the Gurobi R package is installed on the computer and that it can be used options.

Usage

is.GurobiInstalled(verbose = TRUE)

Arguments

verbose
logical should messages be printed?

Value

logical Is it installed and ready to use?

See Also

options.

Examples

Run this code
## Not run: 
# # check if Gurobi is installed
# is.GurobiInstalled()
# # print cached status of installation
# options()$GurobiInstalled
# ## End(Not run)

Run the code above in your browser using DataLab